from glitchtech_ai.tools import OpenAi, ManageSettings


def validate_token(ms: ManageSettings, oa: OpenAi):
    if not ms.settings_exist() and not oa.token:
        command = input('No API token detected. Please enter valid OpenAI token: ')
        ms.store_setting(key="open_ai_token", value=command)
        oa.update_token(token=ms.retrieve_setting(key="open_ai_token"))

    if ms.settings_exist() and oa.token:
        return True


def main():
    ms = ManageSettings(project_name="GlitchTech-AI")
    oa = OpenAi(prompt="You are a tired butler.")

    prompt = "[ OA ]-> "

    validate_token(ms=ms, oa=oa)

    while True:
        validate_token(ms=ms, oa=oa)

        command = input(prompt)
        if command.lower() in ['quit', 'q', 'exit', 'e']:
            print(oa.session_usage)
            break
        elif command:
            print(oa.chat_completions(user_input=command))


if __name__ == '__main__':
    validate_token()



import os
import platform

from configparser import ConfigParser


class ManageSettings:
    def __init__(self, project_name: str):
        self.project_name = project_name

        self.project_path = self._determine_project_path()
        self.settings_file_name = "settings.conf"

        self.settings_file_path = os.path.join(self.project_path, self.settings_file_name)

    def _determine_project_path(self):
        if platform.system() == "Linux":
            return f"{os.environ['HOME']}/.cache/{self.project_name}"

        if platform.system() == "Windows":
            return f"{os.environ['LOCALAPPDATA']}/{self.project_name}"

    def settings_exist(self) -> bool:
        return os.path.exists(self.settings_file_path)

    def store_setting(self, key: str, value: str = None):
        if not os.path.exists(self.project_path):
            os.makedirs(self.project_path)

        config = ConfigParser()
        config.read(self.settings_file_path)
        config.add_section('main')

        if key and value:
            config.set('main', key, value)

        with open(self.settings_file_path, 'w') as f:
            config.write(f)

    def retrieve_setting(self, key):
        config = ConfigParser()
        config.read(self.settings_file_path)
        return config.get('main', key)


if __name__ == '__main__':
    ls = ManageSettings(project_name="PersonalProject")
    ls.store_setting(key="open_ai_token", value="PRIVATE")
